==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/ro.js <==
/**
 * Romanian
 */

$.Editable.LANGS['ro'] = {
  translation: {
    "Bold": "\u00cengro\u015fat",
    "Italic": "Italic",
    "Underline": "Subliniat",
    "Strikethrough": "T\u0103iat",
    "Font Size": "Dimensiune font",
    "Color": "Culoare",
    "Background Color": "Culoare fundal",
    "Text Color": "Culoare text",
    "Format Block": "Formate",
    "Normal": "Normal",
    "Paragraph": "Paragraf",
    "Code": "Cod",
    "Quote": "Citat",
    "Heading 1": "Antent 1",
    "Heading 2": "Antent 2",
    "Heading 3": "Antent 3",
    "Heading 4": "Antent 4",
    "Heading 5": "Antent 5",
    "Heading 6": "Antent 6",
    "Alignment": "Aliniere",
    "Align Left": "Aliniere la st\u00e2nga",
    "Align Center": "Aliniere la centru",
    "Align Right": "Aliniere la dreapta",
    "Justify": "Aliniere pe toat\u0103 l\u0103\u021bimea",
    "Numbered List": "List\u0103 ordonat\u0103",
    "Bulleted List": "List\u0103 neordonat\u0103",
    "Indent Less": "De-indenteaz\u0103",
    "Indent More": "Indenteaz\u0103",
    "Select All": "Selecteaz\u0103 tot",
    "Insert Link": "Inserare link",
    "Insert Image": "Inserare imagine",
    "Insert Video": "Inserare video",
    "Undo": "Reexecut\u0103",
    "Redo": "Dezexecut\u0103",
    "Show HTML": "Arat\u0103 HTML",
    "Float Left": "St\u00e2nga",
    "Float None": "Niciunul",
    "Float Right": "Dreapta",
    "Replace Image": "\u00cenlocuie\u015fte imaginea",
    "Remove Image": "\u0218terge imaginea",
    "Title": "Titlu",
    "Insert image": "Inserare imagine",
    "Drop image": "Trage imagine",
    "or click": "f\u0103 click",
    "Enter URL": "Introdu URL",
    "Please wait!": "V\u0103 rug\u0103m a\u015ftepta\u021bi!",
    "Are you sure? Image will be deleted.": "Sunte\u021bi sigur? Imaginea va fi \u015ftears\u0103.",
    "UNLINK": "\u0218terge link-ul",
    "Open in new tab": "Deschide \u00EEn tab nou",
    "Type something": "Tasteaz\u0103 ceva",
    "Cancel": "Anulare",
    "OK": "Ok",
    "Manage images": "Gestionare imagini",
    "Delete": "\u015eterge",
    "Font Family": "Font",
    "Insert Horizontal Line": "Inserare linie orizontal\u0103"
  },
  direction: "ltr"
};

==> django-froala-editor-0.8.7.tar.gz: django-froala-editor-0.8.7/froala_editor/static/froala_editor/js/langs/ro.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Romanian
 */

$.Editable.LANGS['ro'] = {
  translation: {
    "Bold": "\u00cengro\u015fat",
    "Italic": "Italic",
    "Underline": "Subliniat",
    "Strikethrough": "T\u0103iat",
    "Font Size": "Dimensiune font",
    "Color": "Culoare",
    "Background Color": "Culoare fundal",
    "Text Color": "Culoare text",
    "Format Block": "Formate",
    "Normal": "Normal",
    "Paragraph": "Paragraf",
    "Code": "Cod",
    "Quote": "Citat",
    "Heading 1": "Antent 1",
    "Heading 2": "Antent 2",
    "Heading 3": "Antent 3",
    "Heading 4": "Antent 4",
    "Heading 5": "Antent 5",
    "Heading 6": "Antent 6",
    "Alignment": "Aliniere",
    "Align Left": "Aliniere la st\u00e2nga",
    "Align Center": "Aliniere la centru",
    "Align Right": "Aliniere la dreapta",
    "Justify": "Aliniere pe toat\u0103 l\u0103\u021bimea",
    "Numbered List": "List\u0103 ordonat\u0103",
    "Bulleted List": "List\u0103 neordonat\u0103",
    "Indent Less": "De-indenteaz\u0103",
    "Indent More": "Indenteaz\u0103",
    "Select All": "Selecteaz\u0103 tot",
    "Insert Link": "Inserare link",
    "Insert Image": "Inserare imagine",
    "Insert Video": "Inserare video",
    "Undo": "Reexecut\u0103",
    "Redo": "Dezexecut\u0103",
    "Show HTML": "Arat\u0103 HTML",
    "Float Left": "St\u00e2nga",
    "Float None": "Niciunul",
    "Float Right": "Dreapta",
    "Replace Image": "\u00cenlocuie\u015fte imaginea",
    "Remove Image": "\u0218terge imaginea",
    "Title": "Titlu",
    "Insert image": "Inserare imagine",
    "Drop image": "Trage imagine",
    "or click": "f\u0103 click",
    "Enter URL": "Introdu URL",
    "Please wait!": "V\u0103 rug\u0103m a\u015ftepta\u021bi!",
    "Are you sure? Image will be deleted.": "Sunte\u021bi sigur? Imaginea va fi \u015ftears\u0103.",
    "UNLINK": "\u0218terge link-ul",
    "Open in new tab": "Deschide \u00EEn tab nou",
    "Type something": "Tasteaz\u0103 ceva",
    "Cancel": "Anulare",
    "OK": "Ok",
    "Manage images": "Gestionare imagini",
    "Delete": "\u015eterge",
    "Font Family": "Font",
    "Insert Horizontal Line": "Inserare linie orizontal\u0103",
    "Table": "Tabel",
    "Insert table": "Inserare tabel",
    "Cell": "Celula",
    "Row": "Linie",
    "Column": "Coloan\u0103",
    "Delete table": "\u0218terge tabel",
    "Insert cell before": "Insereaz\u0103 celula \u00eenainte",
    "Insert cell after": "Insereaz\u0103 celula dup\u0103",
    "Delete cell": "\u0218terge celula",
    "Merge cells": "Une\u015fte celulele",
    "Horizontal split": "\u00cemparte orizontal",
    "Vertical split": "\u00cemparte vertical",
    "Insert row above": "Insereaz\u0103 linie \u00eenainte",
    "Insert row below": "Insereaz\u0103 linie dup\u0103",
    "Delete row": "\u015eterge linia",
    "Insert column before": "Insereaz\u0103 coloan\u0103 \u00eenainte",
    "Insert column after": "Insereaz\u0103 coloan\u0103 dup\u0103",
    "Delete column": "\u015eterge coloana"
  },
  direction: "ltr"
};
